@@ -9,6 +9,8 @@
 #define   MShare             L"\nTrial version             Type RAR -? for help\n"
 #define   MUCopyright        L"\nUNRAR %s freeware      Copyright (c) 1993-%d Alexander Roshal\n"
 #define   MBeta              L"beta"
+#define   Mx86               L"x86"
+#define   Mx64               L"x64"
 #define   MMonthJan          L"Jan"
 #define   MMonthFeb          L"Feb"
 #define   MMonthMar          L"Mar"
@@ -83,6 +85,7 @@
 #define   MCHelpSwINUL       L"\n  inul          Disable all messages"
 #define   MCHelpSwIOFF       L"\n  ioff          Turn PC off after completing an operation"
 #define   MCHelpSwISND       L"\n  isnd          Enable sound"
+#define   MCHelpSwIVER       L"\n  iver          Display the version number"
 #define   MCHelpSwK          L"\n  k             Lock archive"
 #define   MCHelpSwKB         L"\n  kb            Keep broken extracted files"
 #define   MCHelpSwLog        L"\n  log[f][=name] Write names to log file"
@@ -99,7 +102,8 @@
 #define   MCHelpSwOC         L"\n  oc            Set NTFS Compressed attribute"
 #define   MCHelpSwOH         L"\n  oh            Save hard links as the link instead of the file"
 #define   MCHelpSwOI         L"\n  oi[0-4][:min] Save identical files as references"
-#define   MCHelpSwOL         L"\n  ol            Save symbolic links as the link instead of the file"
+#define   MCHelpSwOL         L"\n  ol[a]         Process symbolic links as the link [absolute paths]"
+#define   MCHelpSwONI        L"\n  oni           Allow potentially incompatible names"
 #define   MCHelpSwOR         L"\n  or            Rename files automatically"
 #define   MCHelpSwOS         L"\n  os            Save NTFS streams"
 #define   MCHelpSwOW         L"\n  ow            Save or restore file owner and group"
@@ -237,7 +241,7 @@
 #define   MDeleting          L"\nDeleting %s"
 #define   MEraseArc          L"\nErasing empty archive %s"
 #define   MNoDelFiles        L"\nNo files to delete"
-#define   MLogTitle          L"\n\n--------  %2d %s %d, archive %s\n"
+#define   MLogTitle          L"--------  %2d %s %d, archive %s"
 #define   MPathTooLong       L"\nERROR: Path too long\n"
 #define   MListArchive       L"Archive"
 #define   MListDetails       L"Details"
@@ -248,8 +252,8 @@
 #define   MListLock          L"lock"
 #define   MListEnc           L"encrypted"
 #define   MListEncHead       L"encrypted headers"
-#define   MListTitleL        L" Attributes      Size    Date   Time   Name"
-#define   MListTitleV        L" Attributes      Size    Packed Ratio   Date   Time   Checksum  Name"
+#define   MListTitleL        L" Attributes      Size     Date    Time   Name"
+#define   MListTitleV        L" Attributes      Size    Packed Ratio    Date    Time   Checksum  Name"
 #define   MListName          L"Name"
 #define   MListType          L"Type"
 #define   MListFile          L"File"
@@ -258,7 +262,7 @@
 #define   MListWSymlink      L"Windows symbolic link"
 #define   MListJunction      L"NTFS junction point"
 #define   MListHardlink      L"Hard link"
-#define   MListCopy          L"File copy"
+#define   MListCopy          L"File reference"
 #define   MListStream        L"NTFS alternate data stream"
 #define   MListTarget        L"Target"
 #define   MListSize          L"Size"
@@ -375,7 +379,7 @@
 #define   MNumFound          L"%d found."
 #define   MUnknownExtra      L"\nUnknown extra field in %s."
 #define   MCopyError         L"\nCannot copy %s to %s."
-#define   MCopyErrorHint     L"\nYou need to unpack the entire archive to create file copy entries."
+#define   MCopyErrorHint     L"\nYou need to unpack the entire archive to create file reference entries."
 #define   MCopyingData       L"\nCopying data"
 #define   MErrCreateLnkS     L"\nCannot create symbolic link %s"
 #define   MErrCreateLnkH     L"\nCannot create hard link %s"
