@@ -144,9 +144,16 @@ bool IsDriveDiv(int Ch)
 }
 
 
+bool IsDriveLetter(const wchar *Path)
+{
+  wchar Letter=etoupperw(Path[0]);
+  return Letter>='A' && Letter<='Z' && IsDriveDiv(Path[1]);
+}
+
+
 int GetPathDisk(const wchar *Path)
 {
-  if (IsDiskLetter(Path))
+  if (IsDriveLetter(Path))
     return etoupperw(*Path)-'A';
   else
     return -1;
@@ -534,7 +541,7 @@ bool IsFullPath(const wchar *Path)
     return true;
 */
 #if defined(_WIN_ALL) || defined(_EMX)
-  return Path[0]=='\\' && Path[1]=='\\' || IsDiskLetter(Path) && IsPathDiv(Path[2]);
+  return Path[0]=='\\' && Path[1]=='\\' || IsDriveLetter(Path) && IsPathDiv(Path[2]);
 #else
   return IsPathDiv(Path[0]);
 #endif
@@ -547,17 +554,10 @@ bool IsFullRootPath(const wchar *Path)
 }
 
 
-bool IsDiskLetter(const wchar *Path)
-{
-  wchar Letter=etoupperw(Path[0]);
-  return Letter>='A' && Letter<='Z' && IsDriveDiv(Path[1]);
-}
-
-
 void GetPathRoot(const wchar *Path,wchar *Root,size_t MaxSize)
 {
   *Root=0;
-  if (IsDiskLetter(Path))
+  if (IsDriveLetter(Path))
     swprintf(Root,MaxSize,L"%c:\\",*Path);
   else
     if (Path[0]=='\\' && Path[1]=='\\')
@@ -873,7 +873,7 @@ wchar* GetWideName(const char *Name,const wchar *NameW,wchar *DestW,size_t DestS
   if (DestSize>0)
     DestW[DestSize-1]=0;
 
-  return(DestW);
+  return DestW;
 }
 
 
@@ -887,11 +887,11 @@ bool GetWinLongPath(const wchar *Src,wchar *Dest,size_t MaxSize)
     return false;
   const wchar *Prefix=L"\\\\?\\";
   const size_t PrefixLength=4;
-  bool FullPath=IsDiskLetter(Src) && IsPathDiv(Src[2]);
+  bool FullPath=IsDriveLetter(Src) && IsPathDiv(Src[2]);
   size_t SrcLength=wcslen(Src);
   if (IsFullPath(Src)) // Paths in d:\path\name format.
   {
-    if (IsDiskLetter(Src))
+    if (IsDriveLetter(Src))
     {
       if (MaxSize<=PrefixLength+SrcLength)
         return false;
@@ -945,4 +945,39 @@ bool GetWinLongPath(const wchar *Src,wchar *Dest,size_t MaxSize)
   }
   return false;
 }
+
+
+// Convert Unix, OS X and Android decomposed chracters to Windows precomposed.
+void ConvertToPrecomposed(wchar *Name,size_t NameSize)
+{
+  wchar FileName[NM];
+  if (WinNT()>=WNT_VISTA && // MAP_PRECOMPOSED is not supported in XP.
+      FoldString(MAP_PRECOMPOSED,Name,-1,FileName,ASIZE(FileName))!=0)
+  {
+    FileName[ASIZE(FileName)-1]=0;
+    wcsncpyz(Name,FileName,NameSize);
+  }
+}
+
+
+// Remove trailing spaces and dots in file name and in dir names in path.
+void MakeNameCompatible(wchar *Name)
+{
+  int Src=0,Dest=0;
+  while (true)
+  {
+    if (IsPathDiv(Name[Src]) || Name[Src]==0)
+      for (int I=Dest-1;I>0 && (Name[I]==' ' || Name[I]=='.');I--)
+      {
+        if (IsPathDiv(Name[I-1])) // Permit path1/./path2 paths.
+          break;
+        Dest--;
+      }
+    Name[Dest]=Name[Src];
+    if (Name[Src]==0)
+      break;
+    Src++;
+    Dest++;
+  }
+}
 #endif
