@@ -137,19 +137,25 @@ void Unpack::Init(size_t WinSize,bool Solid)
 
 void Unpack::DoUnpack(int Method,bool Solid)
 {
+  // Methods <50 will crash in Fragmented mode when accessing NULL Window.
+  // They cannot be called in such mode now, but we check it below anyway
+  // just for extra safety.
   switch(Method)
   {
 #ifndef SFX_MODULE
     case 15: // rar 1.5 compression
-      Unpack15(Solid);
+      if (!Fragmented)
+        Unpack15(Solid);
       break;
     case 20: // rar 2.x compression
     case 26: // files larger than 2GB
-      Unpack20(Solid);
+      if (!Fragmented)
+        Unpack20(Solid);
       break;
 #endif
     case 29: // rar 3.x compression
-      Unpack29(Solid);
+      if (!Fragmented)
+        Unpack29(Solid);
       break;
     case 50: // RAR 5.0 compression algorithm.
 #ifdef RAR_SMP
